@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -25,6 +25,7 @@
 
 #include "alligator-version.h"
 #include "alligatorsettings.h"
+#include "contenthelper.h"
 #include "database.h"
 #include "entriesmodel.h"
 #include "entriesproxymodel.h"
@@ -79,25 +80,12 @@ int main(int argc, char *argv[])
                      QStringLiteral(ALLIGATOR_VERSION_STRING),
                      i18n("Feed Reader"),
                      KAboutLicense::GPL,
-                     i18n("© 2020-2022 KDE Community"));
-    about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("fella@posteo.de"), QStringLiteral("https://tobiasfella.de"));
+                     i18n("© 2020-2023 KDE Community"));
+    about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("tobias.fella@kde.org"), QStringLiteral("https://tobiasfella.de"));
     KAboutData::setApplicationData(about);
 
-    qmlRegisterType<FeedsModel>("org.kde.alligator", 1, 0, "FeedsModel");
-    qmlRegisterType<FeedGroupsModel>("org.kde.alligator", 1, 0, "FeedGroupsModel");
-    qmlRegisterType<FeedsProxyModel>("org.kde.alligator", 1, 0, "FeedsProxyModel");
-
-    qmlRegisterType<EntriesModel>("org.kde.alligator", 1, 0, "EntriesModel");
-    qmlRegisterType<EntriesProxyModel>("org.kde.alligator", 1, 0, "EntriesProxyModel");
-
-    qmlRegisterSingletonType("org.kde.alligator", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
-        return engine->toScriptValue(KAboutData::applicationData());
-    });
-
     AlligatorSettings settings;
-    qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "Config", &settings);
-    qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "Fetcher", &Fetcher::instance());
-    qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "Database", &Database::instance());
+    qmlRegisterSingletonInstance("org.kde.alligator.config", 1, 0, "Config", &settings);
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
@@ -121,7 +109,7 @@ int main(int argc, char *argv[])
 
     Database::instance();
 
-    engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
+    engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
